==> aws-cdk.aws-wisdom-1.134.0.tar.gz: package/.warnings.jsii.js <==
function _aws_cdk_aws_wisdom_CfnAssistantProps(p) {
    if (p == null)
        return;
    visitedObjects.add(p);
    if (!visitedObjects.has(p.tags))
        require("@aws-cdk/core/.warnings.jsii.js")._aws_cdk_core_CfnTag(p.tags);
    visitedObjects.delete(p);
}
function _aws_cdk_aws_wisdom_CfnAssistantAssociationProps(p) {
    if (p == null)
        return;
    visitedObjects.add(p);
    if (!visitedObjects.has(p.association))
        _aws_cdk_aws_wisdom_CfnAssistantAssociation_AssociationDataProperty(p.association);
    if (!visitedObjects.has(p.tags))
        require("@aws-cdk/core/.warnings.jsii.js")._aws_cdk_core_CfnTag(p.tags);
    visitedObjects.delete(p);
}
function _aws_cdk_aws_wisdom_CfnKnowledgeBaseProps(p) {
    if (p == null)
        return;
    visitedObjects.add(p);
    if (!visitedObjects.has(p.tags))
        require("@aws-cdk/core/.warnings.jsii.js")._aws_cdk_core_CfnTag(p.tags);
    visitedObjects.delete(p);
}
function _aws_cdk_aws_wisdom_CfnAssistant(p) {
}
function _aws_cdk_aws_wisdom_CfnAssistant_ServerSideEncryptionConfigurationProperty(p) {
}
function _aws_cdk_aws_wisdom_CfnAssistantAssociation(p) {
}
function _aws_cdk_aws_wisdom_CfnAssistantAssociation_AssociationDataProperty(p) {
}
function _aws_cdk_aws_wisdom_CfnKnowledgeBase(p) {
}
function _aws_cdk_aws_wisdom_CfnKnowledgeBase_RenderingConfigurationProperty(p) {
}
function _aws_cdk_aws_wisdom_CfnKnowledgeBase_ServerSideEncryptionConfigurationProperty(p) {
}
function _aws_cdk_aws_wisdom_CfnKnowledgeBase_AppIntegrationsConfigurationProperty(p) {
}
function _aws_cdk_aws_wisdom_CfnKnowledgeBase_SourceConfigurationProperty(p) {
}
function print(name, deprecationMessage) {
    const deprecated = process.env.JSII_DEPRECATED;
    const deprecationMode = ["warn", "fail", "quiet"].includes(deprecated) ? deprecated : "warn";
    const message = `${name} is deprecated.\n  ${deprecationMessage}\n  This API will be removed in the next major release.`;
    switch (deprecationMode) {
        case "fail":
            throw new DeprecationError(message);
        case "warn":
            console.warn("[WARNING]", message);
            break;
    }
}
const visitedObjects = new Set();
class DeprecationError extends Error {
}
module.exports = { print, _aws_cdk_aws_wisdom_CfnAssistantProps, _aws_cdk_aws_wisdom_CfnAssistantAssociationProps, _aws_cdk_aws_wisdom_CfnKnowledgeBaseProps, _aws_cdk_aws_wisdom_CfnAssistant, _aws_cdk_aws_wisdom_CfnAssistant_ServerSideEncryptionConfigurationProperty, _aws_cdk_aws_wisdom_CfnAssistantAssociation, _aws_cdk_aws_wisdom_CfnAssistantAssociation_AssociationDataProperty, _aws_cdk_aws_wisdom_CfnKnowledgeBase, _aws_cdk_aws_wisdom_CfnKnowledgeBase_RenderingConfigurationProperty, _aws_cdk_aws_wisdom_CfnKnowledgeBase_ServerSideEncryptionConfigurationProperty, _aws_cdk_aws_wisdom_CfnKnowledgeBase_AppIntegrationsConfigurationProperty, _aws_cdk_aws_wisdom_CfnKnowledgeBase_SourceConfigurationProperty };
module.exports.DeprecationError = DeprecationError;

==> aws-cdk.aws-wisdom-1.138.0.tar.gz: package/.warnings.jsii.js <==
function _aws_cdk_aws_wisdom_CfnAssistantAssociationProps(p) {
    if (p == null)
        return;
    visitedObjects.add(p);
    if (!visitedObjects.has(p.association))
        _aws_cdk_aws_wisdom_CfnAssistantAssociation_AssociationDataProperty(p.association);
    if (!visitedObjects.has(p.tags))
        require("@aws-cdk/core/.warnings.jsii.js")._aws_cdk_core_CfnTag(p.tags);
    visitedObjects.delete(p);
}
function _aws_cdk_aws_wisdom_CfnAssistantProps(p) {
    if (p == null)
        return;
    visitedObjects.add(p);
    if (!visitedObjects.has(p.tags))
        require("@aws-cdk/core/.warnings.jsii.js")._aws_cdk_core_CfnTag(p.tags);
    visitedObjects.delete(p);
}
function _aws_cdk_aws_wisdom_CfnKnowledgeBaseProps(p) {
    if (p == null)
        return;
    visitedObjects.add(p);
    if (!visitedObjects.has(p.tags))
        require("@aws-cdk/core/.warnings.jsii.js")._aws_cdk_core_CfnTag(p.tags);
    visitedObjects.delete(p);
}
function _aws_cdk_aws_wisdom_CfnAssistant(p) {
}
function _aws_cdk_aws_wisdom_CfnAssistant_ServerSideEncryptionConfigurationProperty(p) {
}
function _aws_cdk_aws_wisdom_CfnAssistantAssociation(p) {
}
function _aws_cdk_aws_wisdom_CfnAssistantAssociation_AssociationDataProperty(p) {
}
function _aws_cdk_aws_wisdom_CfnKnowledgeBase(p) {
}
function _aws_cdk_aws_wisdom_CfnKnowledgeBase_RenderingConfigurationProperty(p) {
}
function _aws_cdk_aws_wisdom_CfnKnowledgeBase_ServerSideEncryptionConfigurationProperty(p) {
}
function _aws_cdk_aws_wisdom_CfnKnowledgeBase_AppIntegrationsConfigurationProperty(p) {
}
function _aws_cdk_aws_wisdom_CfnKnowledgeBase_SourceConfigurationProperty(p) {
}
function print(name, deprecationMessage) {
    const deprecated = process.env.JSII_DEPRECATED;
    const deprecationMode = ["warn", "fail", "quiet"].includes(deprecated) ? deprecated : "warn";
    const message = `${name} is deprecated.\n  ${deprecationMessage}\n  This API will be removed in the next major release.`;
    switch (deprecationMode) {
        case "fail":
            throw new DeprecationError(message);
        case "warn":
            console.warn("[WARNING]", message);
            break;
    }
}
const visitedObjects = new Set();
class DeprecationError extends Error {
}
module.exports = { print, _aws_cdk_aws_wisdom_CfnAssistantAssociationProps, _aws_cdk_aws_wisdom_CfnAssistantProps, _aws_cdk_aws_wisdom_CfnKnowledgeBaseProps, _aws_cdk_aws_wisdom_CfnAssistant, _aws_cdk_aws_wisdom_CfnAssistant_ServerSideEncryptionConfigurationProperty, _aws_cdk_aws_wisdom_CfnAssistantAssociation, _aws_cdk_aws_wisdom_CfnAssistantAssociation_AssociationDataProperty, _aws_cdk_aws_wisdom_CfnKnowledgeBase, _aws_cdk_aws_wisdom_CfnKnowledgeBase_RenderingConfigurationProperty, _aws_cdk_aws_wisdom_CfnKnowledgeBase_ServerSideEncryptionConfigurationProperty, _aws_cdk_aws_wisdom_CfnKnowledgeBase_AppIntegrationsConfigurationProperty, _aws_cdk_aws_wisdom_CfnKnowledgeBase_SourceConfigurationProperty };
module.exports.DeprecationError = DeprecationError;
